# New in version 0.4.4

* Improvements to dataset upload functionality
* Changed pybis dependency to version == 1.36.2

# New in version 0.4.3

* Changed upload prints to be more readable
* Changed pybis dependency to version == 1.36.1

# New in version 0.4.2

* Added filtering by object in object and data_set search commands
* Added recursive search to object and data_set search commands
* Updated documentation regarding authentication
* Added dataset ids to sample search results
* changed pybis dependency to version == 1.36.0

# New in version 0.4.1

* Fixed parameters for determine_hostname method in addref functionality 

# New in version 0.4.0.1

* Minor fixes to physical data handling

# New in version 0.4.0

* Implementation of physical data handling

# New in version 0.3.0

* changed pybis dependency to version >= 1.33.0

# New in version 0.2.3

* Fixes to CRC32 calculation

# New in version 0.2.2

* added compatibility with git-annex 8.2

# New in version 0.2.1

* first release in pypi
